===============================
TrelloStats
===============================

******* This is not really complete yet - I'll be finishing in the next two weeks ********

.. image:: https://badge.fury.io/py/trellostats.png
    :target: http://badge.fury.io/py/trellostats
    
.. image:: https://travis-ci.org/ActionAgile/trellostats.svg?branch=master
        :target: https://travis-ci.org/actionagile/trellostats

.. image:: https://pypip.in/d/trellostats/badge.png
        :target: https://pypi.python.org/pypi/trellostats


Trello Stats for Winners

* Free software: BSD license
* Documentation: http://trellostats.readthedocs.org.

Features
--------

* Reporting in general (templates)
* Email reporting
* Burndown (points using the [] standard)
* Revenue burn and projected completion costs